/*
  Copyright Red Hat, Inc. 2008

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; version 2.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  If not, write to the
  Free Software Foundation, Inc.,  675 Mass Ave, Cambridge, 
  MA 02139, USA.
*/
#include <stdlib.h>
#include <stdio.h>
#include <errno.h>
#include "metadata.h"

static ra_header_t fsc_version = {
	"0",
	"1",
	"fs",
	"rgmanager 2.0"
};

static ra_desc_t fsc_descs[] = {
	{
		"C",
		"File system agent written in C",
		"File system agent written in C - designed to be a lot "
		"faster than the shell-based one."
	},
	{
		"en",
		"File system agent written in C",
		"File system agent written in C - designed to be a lot "
		"faster than the shell-based one."
	},
	RA_DESC_END
};

static ra_desc_t name_descs[] = {
	{
		"C",
		"Name of file system.",
		"Name of file system.  This is a symbolic name used to help "
		"you remember the purpose of this file system."
	},
	{
		"en",
		"Name of file system.",
		"Name of file system.  This is a symbolic name used to help "
		"you remember the purpose of this file system."
	},
	RA_DESC_END
};

static ra_desc_t device_descs[] = {
	{
		"C",
		"File system device, label, or UUID.",
		"File system device, label, or UUID.  This identifies the "
		"file system you want to mount.  For labels, use "
		"LABEL=mylabel format; for UUIDs, use UUID=myuuid."
	},
	{
		"en",
		"File system device or label",
		"File system device, label, or UUID.  This identifies the "
		"file system you want to mount.  For labels, use "
		"LABEL=mylabel format; for UUIDs, use UUID=myuuid."
	},
	RA_DESC_END
};

static ra_desc_t mp_descs[] = {
	{
		"C",
		"File system mountpoint.",
		"File system mountpoint."
	},
	{
		"en",
		"File system mountpoint.",
		"File system mountpoint."
	},
	RA_DESC_END
};

static ra_desc_t fstype_descs[] = {
	{
		"C",
		"File system type.",
		"File system type.  This can be any file system type "
		"supported by your kernel."
	},
	{
		"en",
		"File system type.",
		"File system type.  This can be any file system type "
		"supported by your kernel."
	},
	RA_DESC_END
};

static ra_desc_t opt_descs[] = {
	{
		"C",
		"File system mount options.",
		"File system mount options.  See the mount(1) manual page for"
		" a complete list."
	},
	{
		"en",
		"File system mount options.",
		"File system mount options.  See the mount(1) manual page for"
		" a complete list."
	},
	RA_DESC_END
};

static ra_desc_t self_fence_descs[] = {
	{
		"C",
		"Self fencing option.",
		"Self fencing option.  If set to 0, (default), the fsc agent"
		" will return an error code if it fails to unmount the file"
		" system during the stop operation.  If set to 1, fsc will "
		"reboot the machine, allowing recovery of the service on "
		"another node in the cluster."
	},
	{
		"en",
		"Self fencing option.",
		"Self fencing option.  If set to 0, (default), the fsc agent"
		" will return an error code if it fails to unmount the file"
		" system during the stop operation.  If set to 1, fsc will "
		"reboot the machine, allowing recovery of the service on "
		"another node in the cluster."
	},
	RA_DESC_END
};

static ra_desc_t external_mount_descs[] = {
	{
		"C",
		"Use mount/umount commands instead of syscalls.",
		"Use mount/umount commands instead of syscalls.  This trades "
		"some amount of performance for usability.  If set to 0 "
		"(default), fsc will use syscalls (which is very fast),"
		" but not update /etc/mtab."
	},
	{
		"en",
		"Use mount/umount commands instead of syscalls.",
		"Use mount/umount commands instead of syscalls.  This trades "
		"some amount of performance for usability.  If set to 0 "
		"(default), fsc will use syscalls (which is very fast),"
		" but not update /etc/mtab."
	},
	RA_DESC_END
};

static ra_desc_t fsid_descs[] = {
	{
		"C",
		"File system ID (for NFS).",
		"File system ID (for NFS).  If the service fails over, "
		"NFS clients will normally reacquire file handles on the new "
		"server using the device major/minor numbers.  However, in a "
		"cluster, there is no guarantee that every device major/minor "
		"will be consistent cluster-wide.  The NFS FSID fixes this "
		"by using a static value instead of the device major/minor "
		"numbers.  This number can be any 32-bit integer, and must "
		"be unique across all file systems used for NFS services in "
		"the cluster."
	},
	{
		"en",
		"File system ID (for NFS).",
		"File system ID (for NFS).  If the service fails over, "
		"NFS clients will normally reacquire file handles on the new "
		"server using the device major/minor numbers.  However, in a "
		"cluster, there is no guarantee that every device major/minor "
		"will be consistent cluster-wide.  The NFS FSID fixes this "
		"by using a static value instead of the device major/minor "
		"numbers.  This number can be any 32-bit integer, and must "
		"be unique across all file systems used for NFS services in "
		"the cluster."
	},
	RA_DESC_END
};

static ra_param_t fsc_params[] = {
	{
		"name",
		NULL,
		name_descs,
		"string",
		NULL,
		RA_FL_PRIMARY,
		0
	},
	{
		"device",
		NULL,
		device_descs,
		"string",
		NULL,
		RA_FL_UNIQUE,
		0
	},
	{
		"mountpoint",
		NULL,
		mp_descs,
		"string",
		NULL,
		RA_FL_UNIQUE,
		0
	},
	{
		"fstype",
		NULL,
		fstype_descs,
		"string",
		"ext3",
		0,
		0
	},
	{
		"options",
		NULL,
		opt_descs,
		"string",
		NULL,
		0,
		0
	},
	{
		"self_fence",
		NULL,
		self_fence_descs,
		"boolean",
		"0",
		0,
		0
	},
	{
		"external_mount",
		NULL,
		external_mount_descs,
		"boolean",
		"0",
		0,
		0
	},
	{
		"fsid",
		NULL,
		fsid_descs,
		"integer",
		NULL,
		0,
		0
	},
	RA_PARAM_END
};

static ra_act_t fsc_actions[] = {
	{
		"start",
		"30s",
		NULL,
		NULL
	},
	{
		"stop",
		"30s",
		NULL,
		NULL
	},
	{
		"status",
		"30s",
		"30s",
		NULL
	},
	{
		"validate-all",
		"30s",
		NULL,
		NULL
	},
	{
		"meta-data",
		"30s",
		NULL,
		NULL
	},
	RA_ACT_END
};


ra_info_t fsc_agent = {
	&fsc_version,
	fsc_descs,
	fsc_params,
	fsc_actions
};

